ProjError

Enum ProjError 

#[non_exhaustive]
pub enum ProjError {
Show 23 variants InvalidOp, WrongSyntax, MissingArg, IllegalArgValue, MutuallyExclusiveArgs, FileNotFound, NotEllipsoid, CoordTransfm, InvalidCoord, OutsideProjectionDomain, NoOperation, OutsideGrid, GridAtNodata, NoConvergence, MissingTime, InvalidCrs { message: String, suggestion: Option<String>, }, OutOfBounds { message: String, suggestion: Option<String>, }, ProjectionFailed { message: String, }, UnsupportedOperation, Other, ApiMisuse, NoInverseOp, NetworkError,
}
Error type mirroring PROJ’s PROJ_ERR_* codes.

The numeric codes are grouped by base values defined in src/proj.h:

  • PROJ_ERR_INVALID_OP (1024): invalid operation / wrong setup.
  • PROJ_ERR_COORD_TRANSFM (2048): coordinate transformation failures.
  • PROJ_ERR_OTHER (4096): all other errors.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidOp

Generic invalid operation (PROJ_ERR_INVALID_OP = 1024).



WrongSyntax

Invalid PROJ string syntax (PROJ_ERR_INVALID_OP_WRONG_SYNTAX = 1025).



MissingArg

Missing required operation parameter (PROJ_ERR_INVALID_OP_MISSING_ARG = 1026).



IllegalArgValue

One of the operation parameters has an illegal value (PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE = 1027).



MutuallyExclusiveArgs

Mutually exclusive arguments (PROJ_ERR_INVALID_OP_MUTUALLY_EXCLUSIVE_ARGS = 1028).



FileNotFound

File not found or with invalid content (PROJ_ERR_INVALID_OP_FILE_NOT_FOUND_OR_INVALID = 1029).



NotEllipsoid

Value does not correspond to an ellipsoid (maps to code 1027, same as ProjError::IllegalArgValue).



CoordTransfm

Generic error of coordinate transformation (PROJ_ERR_COORD_TRANSFM = 2048).



InvalidCoord

Invalid coordinate (PROJ_ERR_COORD_TRANSFM_INVALID_COORD = 2049).



OutsideProjectionDomain

Coordinate outside projection domain (PROJ_ERR_COORD_TRANSFM_OUTSIDE_PROJECTION_DOMAIN = 2050).



NoOperation

No operation found matching criteria (PROJ_ERR_COORD_TRANSFM_NO_OPERATION = 2051).



OutsideGrid

Point to transform falls outside grid or subgrid (PROJ_ERR_COORD_TRANSFM_OUTSIDE_GRID = 2052).



GridAtNodata

Point to transform falls in a grid cell that evaluates to nodata (PROJ_ERR_COORD_TRANSFM_GRID_AT_NODATA = 2053).



NoConvergence

Iterative algorithm did not converge (PROJ_ERR_COORD_TRANSFM_NO_CONVERGENCE = 2054).



MissingTime

Missing required time coordinate (PROJ_ERR_COORD_TRANSFM_MISSING_TIME = 2055).



InvalidCrs

Invalid CRS definition with a descriptive message.

Use this variant when the error is specifically a CRS definition problem and you can provide a helpful message (and optionally a suggestion for fixing it).

Fields

message: String

Human-readable description of the problem.

suggestion: Option<String>

Optional suggestion for resolving the error.



OutOfBounds

Coordinate out of bounds.

Carries a descriptive message and an optional suggestion.

Fields

message: String

Human-readable description of the problem.

suggestion: Option<String>

Optional suggestion for resolving the error.



ProjectionFailed

Projection computation failed.

Carries a descriptive message about the computation failure.

Fields

message: String

Human-readable description of the failure.



UnsupportedOperation

Operation not supported (e.g. AD path not implemented for this projection).



Other

Other error (PROJ_ERR_OTHER = 4096).



ApiMisuse

Error caused by incorrect use of PROJ API (PROJ_ERR_OTHER_API_MISUSE = 4097).



NoInverseOp

No inverse operation (PROJ_ERR_OTHER_NO_INVERSE_OP = 4098).



NetworkError

Failure when accessing a network resource (PROJ_ERR_OTHER_NETWORK_ERROR = 4099).

Implementations

Source

impl ProjError

pub fn code(&self) -> i32

Ported from src/proj.h (PROJ_ERR_* numeric codes)

pub fn suggestion(&self) -> Option<&str>

Returns a human-readable suggestion for resolving this error, if one is available.

Returns Some for variants that carry a suggestion field (when one was provided at construction time) as well as for several well-known unit variants where a static hint is always useful.